@@ -23,7 +23,7 @@ import Data.SBV.Core.Data      (Kind, Outputtable, Penalty,
                                 SFPHalf, SFPBFloat, SFPSingle, SFPDouble, SFPQuad, SFloatingPoint,
                                 SInt8, SInt16, SInt32, SInt64, SInteger, SList,
                                 SReal, SString, SV, SWord8, SWord16, SWord32,
-                                SWord64, SEither, SRational, SMaybe, SSet, SArray, constrain, (.==))
+                                SWord64, SRational, SSet, SArray, constrain, (.==))
 import Data.SBV.Core.Kind      (BVIsNonZero, ValidFloat)
 import Data.SBV.Core.Model     (Metric(..), SymTuple)
 import Data.SBV.Core.Symbolic  (Objective, OptimizeStyle, Result, VarContext, Symbolic, SBVRunMode, SMTConfig,
@@ -725,24 +725,6 @@ sTuple_ = Trans.sTuple_
 sTuples :: (SymTuple tup, SymVal tup) => [String] -> Symbolic [SBV tup]
 sTuples = Trans.sTuples
 
--- | Declare a named 'Data.SBV.SEither'.
---
--- NB. For a version which generalizes over the underlying monad, see 'Data.SBV.Trans.sEither'
-sEither :: (SymVal a, SymVal b) => String -> Symbolic (SEither a b)
-sEither = Trans.sEither
-
--- | Declare an unnamed 'Data.SBV.SEither'.
---
--- NB. For a version which generalizes over the underlying monad, see 'Data.SBV.Trans.sEither_'
-sEither_ :: (SymVal a, SymVal b) => Symbolic (SEither a b)
-sEither_ = Trans.sEither_
-
--- | Declare a list of 'Data.SBV.SEither' values.
---
--- NB. For a version which generalizes over the underlying monad, see 'Data.SBV.Trans.sEithers'
-sEithers :: (SymVal a, SymVal b) => [String] -> Symbolic [SEither a b]
-sEithers = Trans.sEithers
-
 -- | Declare a named 'Data.SBV.SRational'.
 --
 -- NB. For a version which generalizes over the underlying monad, see 'Data.SBV.Trans.sRational'
@@ -761,24 +743,6 @@ sRational_ = Trans.sRational_
 sRationals :: [String] -> Symbolic [SRational]
 sRationals = Trans.sRationals
 
--- | Declare a named 'Data.SBV.SMaybe'.
---
--- NB. For a version which generalizes over the underlying monad, see 'Data.SBV.Trans.sMaybe'
-sMaybe :: SymVal a => String -> Symbolic (SMaybe a)
-sMaybe = Trans.sMaybe
-
--- | Declare an unnamed 'Data.SBV.SMaybe'.
---
--- NB. For a version which generalizes over the underlying monad, see 'Data.SBV.Trans.sMaybe_'
-sMaybe_ :: SymVal a => Symbolic (SMaybe a)
-sMaybe_ = Trans.sMaybe_
-
--- | Declare a list of 'Data.SBV.SMaybe' values.
---
--- NB. For a version which generalizes over the underlying monad, see 'Data.SBV.Trans.sMaybes'
-sMaybes :: SymVal a => [String] -> Symbolic [SMaybe a]
-sMaybes = Trans.sMaybes
-
 -- | Declare a named 'Data.SBV.SSet'.
 --
 -- NB. For a version which generalizes over the underlying monad, see 'Data.SBV.Trans.sSet'
