@@ -16,7 +16,9 @@
 {-# LANGUAGE DeriveGeneric         #-}
 {-# LANGUAGE FlexibleContexts      #-}
 {-# LANGUAGE FlexibleInstances     #-}
+{-# LANGUAGE GADTs                 #-}
 {-# LANGUAGE MultiParamTypeClasses #-}
+{-# LANGUAGE RankNTypes            #-}
 {-# LANGUAGE ScopedTypeVariables   #-}
 {-# LANGUAGE TypeApplications      #-}
 {-# LANGUAGE TypeFamilies          #-}
@@ -36,7 +38,7 @@ module Data.SBV.Core.Data
  , STuple, STuple2, STuple3, STuple4, STuple5, STuple6, STuple7, STuple8
  , RCSet(..), SSet
  , nan, infinity, sNaN, sInfinity, RoundingMode(..), SRoundingMode
- , SymVal(..)
+ , SymVal(..), SymValInsts(..), symValKinds, SymVals(..)
  , CV(..), CVal(..), AlgReal(..), AlgRealPoly(..), ExtCV(..), GeneralizedCV(..), isRegularCV, cvSameType, cvToBool
  , mkConstCV , mapCV, mapCV2
  , SV(..), trueSV, falseSV, trueCV, falseCV, normCV
@@ -44,6 +46,8 @@ module Data.SBV.Core.Data
  , sTrue, sFalse, sNot, (.&&), (.||), (.<+>), (.~&), (.~|), (.=>), (.<=>), sAnd, sOr, sAny, sAll, fromBool
  , SBV(..), NodeId(..), mkSymSBV
  , sbvToSV, sbvToSymSV, forceSVArg
+ , RList(..), RNil, (:>), rlist2list
+ , SBVs(..), foldlSBVs, mapMSBVs, foldlSymSBVs
  , SBVExpr(..), newExpr
  , cache, Cached, uncache, HasKind(..)
  , Op(..), PBOp(..), FPOp(..), StrOp(..), RegExOp(..), SeqOp(..), RegExp(..), NamedSymVar(..), OvOp(..), getTableIndex
@@ -345,6 +349,51 @@ instance HasKind a => HasKind (SBV a) where
 sbvToSV :: State -> SBV a -> IO SV
 sbvToSV st (SBV s) = svToSV st s
 
+-- | A datakind for lists with cons on the right
+data RList a = RNil | (RList a) :> a
+
+-- | Convert an 'RList' into a reversed standard list
+rlist2listRev :: RList a -> [a]
+rlist2listRev RNil = []
+rlist2listRev (as :> a) = a : rlist2listRev as
+
+-- | Convert an 'RList' into a standard list
+rlist2list :: RList a -> [a]
+rlist2list = reverse . rlist2listRev
+
+-- | Helper for writing types containing @RNil@
+type RNil = 'RNil
+
+-- | Helper for writing types containing @:>@
+type (:>) = '(:>)
+
+-- | A sequence of elements of types @SBV a1,...,SBV an@ given the list
+-- @[a1,...,an]@ of Haskell types
+data SBVs as where
+  SBVsNil  :: SBVs RNil
+  SBVsCons :: SBVs as -> SBV a -> SBVs (as :> a)
+
+-- | Fold a function over each SBV value in an SBVs sequence in a manner similar
+-- to 'foldr' for lists, except backwards because the lists are stored in
+-- reverse order
+foldlSBVs :: (forall a. r -> SBV a -> r) -> r -> SBVs as -> r
+foldlSBVs _ r SBVsNil             = r
+foldlSBVs f r (SBVsCons args arg) = f (foldlSBVs f r args) arg
+
+-- | Map a monadic function over the SBV values in an SBVs sequence in a
+-- manner similar to 'mapM' for lists
+mapMSBVs :: Monad m => (forall a. SBV a -> m r) -> SBVs as -> m (RList r)
+mapMSBVs f = foldlSBVs (\m arg -> (:>) <$> m <*> f arg) (return RNil)
+
+-- | Fold a function over each SBV value in an SBVs sequence in a manner similar
+-- to 'foldr' for lists (but backwards because SBVs have cons on the right),
+-- using 'SymVal' instances for each value
+foldlSymSBVs :: (forall a. SymVal a => r -> SBV a -> r) -> r ->
+                SymValInsts as -> SBVs as -> r
+foldlSymSBVs _ r _                   SBVsNil             = r
+foldlSymSBVs f r (SymValsCons symvs) (SBVsCons args arg) =
+  f (foldlSymSBVs f r symvs args) arg
+
 -------------------------------------------------------------------------
 -- * Symbolic Computations
 -------------------------------------------------------------------------
@@ -631,6 +680,31 @@ class (HasKind a, Typeable a, Arbitrary a) => SymVal a where
   isSymbolic :: SBV a -> Bool
   isSymbolic = not . isConcrete
 
+-- | A sequence of instance dictionaries for each type @ai@ in the type list
+-- @[a1,...,an]@
+data SymValInsts as where
+  SymValsNil :: SymValInsts RNil
+  SymValsCons :: SymVal a => SymValInsts as -> SymValInsts (as :> a)
+
+-- | Get the 'Kind' of each type in the type list of a 'SymValInsts' sequence
+symValKinds :: SymValInsts as -> [Kind]
+symValKinds = rlist2list . helper where
+  helper :: SymValInsts as -> RList Kind
+  helper SymValsNil = RNil
+  helper insts@(SymValsCons insts') = helper insts' :> kindOf (headPrx insts)
+  headPrx :: SymValInsts (bs :> b) -> Proxy b
+  headPrx _ = Proxy
+
+-- | A 'SymVals' is a list of types that all satisfy 'SymVal'
+class SymVals as where
+  symValInsts :: SymValInsts as
+
+instance SymVals RNil where
+  symValInsts = SymValsNil
+
+instance (SymVal a, SymVals as) => SymVals (as :> a) where
+  symValInsts = SymValsCons symValInsts
+
 instance (Random a, SymVal a) => Random (SBV a) where
   randomR (l, h) g = case (unliteral l, unliteral h) of
                        (Just lb, Just hb) -> let (v, g') = randomR (lb, hb) g in (literal (v :: a), g')
