@@ -13,6 +13,7 @@
 {-# LANGUAGE FlexibleContexts    #-}
 {-# LANGUAGE FlexibleInstances   #-}
 {-# LANGUAGE NamedFieldPuns      #-}
+{-# LANGUAGE OverloadedLists     #-}
 {-# LANGUAGE ScopedTypeVariables #-}
 {-# LANGUAGE TypeApplications    #-}
 
@@ -50,7 +51,7 @@ import Data.Dynamic
 
 import Type.Reflection (typeRep)
 
-import qualified Data.SBV.List as SL (nil, (.:))
+import qualified Data.SBV.List as SL ((.:))
 
 -- | A proposition is something SBV is capable of proving/disproving in TP.
 type Proposition a = ( QNot a
@@ -122,14 +123,14 @@ instance (SymVal at, SymVal bt, SymVal ct, SymVal dt, SymVal et) => HasInduction
 instance SymVal x => HasInductionSchema (Forall nm [x] -> SBool) where
    inductionSchema p = proofOf $ internalAxiom ("induct" ++ show (typeRep @[x])) ax
      where pf = p . Forall
-           ax =   sAnd [pf SL.nil, quantifiedBool (\(Forall x) (Forall xs) -> pf xs .=> pf (x SL..: xs))]
+           ax =   sAnd [pf [], quantifiedBool (\(Forall x) (Forall xs) -> pf xs .=> pf (x SL..: xs))]
               .=> quantifiedBool (\(Forall xs) -> pf xs)
 
 -- | Induction schema for lists with one extra argument
 instance (SymVal x, SymVal at) => HasInductionSchema (Forall nm [x] -> Forall an at -> SBool) where
    inductionSchema p = proofOf $ internalAxiom ("induct" ++ show (typeRep @[x]) ++ "1") ax
      where pf xs a = p (Forall xs) (Forall a)
-           ax      = sAnd [ quantifiedBool (\                       (Forall a) -> pf SL.nil a)
+           ax      = sAnd [ quantifiedBool (\                       (Forall a) -> pf [] a)
                           , quantifiedBool (\(Forall x) (Forall xs) (Forall a) -> pf xs a .=> pf (x SL..: xs) a)]
                      .=>    quantifiedBool (\(Forall xs) (Forall a) -> pf xs a)
 
@@ -137,7 +138,7 @@ instance (SymVal x, SymVal at) => HasInductionSchema (Forall nm [x] -> Forall an
 instance (SymVal x, SymVal at, SymVal bt) => HasInductionSchema (Forall nm [x] -> Forall an at -> Forall bn bt -> SBool) where
    inductionSchema p = proofOf $ internalAxiom ("induct" ++ show (typeRep @[x]) ++ "2") ax
      where pf xs a b = p (Forall xs) (Forall a) (Forall b)
-           ax        = sAnd [ quantifiedBool (\                       (Forall a) (Forall b) -> pf SL.nil a b)
+           ax        = sAnd [ quantifiedBool (\                       (Forall a) (Forall b) -> pf [] a b)
                             , quantifiedBool (\(Forall x) (Forall xs) (Forall a) (Forall b) -> pf xs a b .=> pf (x SL..: xs) a b)]
                        .=>    quantifiedBool (\(Forall xs) (Forall a) (Forall b) -> pf xs a b)
 
@@ -145,7 +146,7 @@ instance (SymVal x, SymVal at, SymVal bt) => HasInductionSchema (Forall nm [x] -
 instance (SymVal x, SymVal at, SymVal bt, SymVal ct) => HasInductionSchema (Forall nm [x] -> Forall an at -> Forall bn bt -> Forall cn ct -> SBool) where
    inductionSchema p = proofOf $ internalAxiom ("induct" ++ show (typeRep @[x]) ++ "3") ax
      where pf xs a b c = p (Forall xs) (Forall a) (Forall b) (Forall c)
-           ax          = sAnd [ quantifiedBool (\                       (Forall a) (Forall b) (Forall c) -> pf SL.nil a b c)
+           ax          = sAnd [ quantifiedBool (\                       (Forall a) (Forall b) (Forall c) -> pf [] a b c)
                               , quantifiedBool (\(Forall x) (Forall xs) (Forall a) (Forall b) (Forall c) -> pf xs a b c .=> pf (x SL..: xs) a b c)]
                          .=>    quantifiedBool (\(Forall xs) (Forall a) (Forall b) (Forall c) -> pf xs a b c)
 
@@ -153,7 +154,7 @@ instance (SymVal x, SymVal at, SymVal bt, SymVal ct) => HasInductionSchema (Fora
 instance (SymVal x, SymVal at, SymVal bt, SymVal ct, SymVal dt) => HasInductionSchema (Forall nm [x] -> Forall an at -> Forall bn bt -> Forall cn ct -> Forall dn dt -> SBool) where
    inductionSchema p = proofOf $ internalAxiom ("induct" ++ show (typeRep @[x]) ++ "4") ax
      where pf xs a b c d = p (Forall xs) (Forall a) (Forall b) (Forall c) (Forall d)
-           ax            = sAnd [ quantifiedBool (\                       (Forall a) (Forall b) (Forall c) (Forall d) -> pf SL.nil a b c d)
+           ax            = sAnd [ quantifiedBool (\                       (Forall a) (Forall b) (Forall c) (Forall d) -> pf [] a b c d)
                                 , quantifiedBool (\(Forall x) (Forall xs) (Forall a) (Forall b) (Forall c) (Forall d) -> pf xs a b c d .=> pf (x SL..: xs) a b c d)]
                            .=>    quantifiedBool (\(Forall xs) (Forall a) (Forall b) (Forall c) (Forall d) -> pf xs a b c d)
 
@@ -161,7 +162,7 @@ instance (SymVal x, SymVal at, SymVal bt, SymVal ct, SymVal dt) => HasInductionS
 instance (SymVal x, SymVal at, SymVal bt, SymVal ct, SymVal dt, SymVal et) => HasInductionSchema (Forall nm [x] -> Forall an at -> Forall bn bt -> Forall cn ct -> Forall dn dt -> Forall en et -> SBool) where
    inductionSchema p = proofOf $ internalAxiom ("induct" ++ show (typeRep @[x]) ++ "5") ax
      where pf xs a b c d e = p (Forall xs) (Forall a) (Forall b) (Forall c) (Forall d) (Forall e)
-           ax              = sAnd [ quantifiedBool (\                       (Forall a) (Forall b) (Forall c) (Forall d) (Forall e) -> pf SL.nil a b c d e)
+           ax              = sAnd [ quantifiedBool (\                       (Forall a) (Forall b) (Forall c) (Forall d) (Forall e) -> pf [] a b c d e)
                                   , quantifiedBool (\(Forall x) (Forall xs) (Forall a) (Forall b) (Forall c) (Forall d) (Forall e) -> pf xs a b c d e .=> pf (x SL..: xs) a b c d e)]
                              .=>    quantifiedBool (\(Forall xs) (Forall a) (Forall b) (Forall c) (Forall d) (Forall e) -> pf xs a b c d e)
 
