@@ -23,6 +23,7 @@ import Data.Char     (isAlpha, toUpper)
 import Data.Function (on)
 import Data.List     (intercalate, groupBy)
 import Data.Maybe    (fromMaybe)
+import qualified Data.Text as T
 
 import Data.SBV.Core.AlgReals
 import Data.SBV.Core.Data
@@ -146,8 +147,8 @@ haskell vname vs = intercalate "\n" $ [ "-- Automatically generated by SBV. Do n
         s cv = case kindOf cv of
                   KVar{}            -> error $ "SBV.renderTest: Unexpected: " ++ show (kindOf cv)
                   KBool             -> take 5 (show (cvToBool cv) ++ repeat ' ')
-                  KBounded sgn   sz -> let CInteger w = cvVal cv in shex  False True (sgn, sz) w
-                  KUnbounded        -> let CInteger w = cvVal cv in shexI False True           w
+                  KBounded sgn   sz -> let CInteger w = cvVal cv in T.unpack $ shex  False True (sgn, sz) w
+                  KUnbounded        -> let CInteger w = cvVal cv in T.unpack $ shexI False True           w
                   KFloat            -> let CFloat   w = cvVal cv in showHFloat w
                   KDouble           -> let CDouble  w = cvVal cv in showHDouble w
                   KRational         -> error "SBV.renderTest: Unsupported rational number"
@@ -261,8 +262,8 @@ c n vs = intercalate "\n" $
         v cv = case kindOf cv of
                   KVar{}          -> error $ "SBV.renderTest: Unexpected: " ++ show (kindOf cv)
                   KBool           -> if cvToBool cv then "true " else "false"
-                  KBounded sgn sz -> let CInteger w = cvVal cv in chex  False True (sgn, sz) w
-                  KUnbounded      -> let CInteger w = cvVal cv in shexI False True           w
+                  KBounded sgn sz -> let CInteger w = cvVal cv in T.unpack $ chex  False True (sgn, sz) w
+                  KUnbounded      -> let CInteger w = cvVal cv in T.unpack $ shexI False True           w
                   KFloat          -> let CFloat w   = cvVal cv in showCFloat w
                   KDouble         -> let CDouble w  = cvVal cv in showCDouble w
                   KRational       -> error "SBV.renderTest: Unsupported rational number"
