@@ -18,12 +18,7 @@
 
 
 {-# LANGUAGE CPP                 #-}
-{-# LANGUAGE DeriveAnyClass      #-}
-{-# LANGUAGE DeriveDataTypeable  #-}
-{-# LANGUAGE DataKinds           #-}
-{-# LANGUAGE TypeAbstractions    #-}
 {-# LANGUAGE ScopedTypeVariables #-}
-{-# LANGUAGE StandaloneDeriving  #-}
 {-# LANGUAGE TemplateHaskell     #-}
 
 {-# OPTIONS_GHC -Wall -Werror #-}
@@ -41,7 +36,7 @@ import Data.SBV.TP
 
 -- | Create an uninterpreted type to do the proofs over.
 data T
-mkUninterpretedSort ''T
+mkSymbolic [''T]
 
 -- | Prove that:
 --
