@@ -10,18 +10,14 @@
 -- the constant folding based arithmetic implementation in SBV
 -----------------------------------------------------------------------------
 
-{-# LANGUAGE CPP                #-}
-{-# LANGUAGE DataKinds          #-}
-{-# LANGUAGE DeriveAnyClass     #-}
-{-# LANGUAGE DeriveDataTypeable #-}
-{-# LANGUAGE FlexibleContexts   #-}
-{-# LANGUAGE FlexibleInstances  #-}
-{-# LANGUAGE Rank2Types         #-}
-{-# LANGUAGE StandaloneDeriving #-}
-{-# LANGUAGE TemplateHaskell    #-}
-{-# LANGUAGE TupleSections      #-}
-{-# LANGUAGE TypeApplications   #-}
-{-# LANGUAGE QuasiQuotes        #-}
+{-# LANGUAGE CPP               #-}
+{-# LANGUAGE DataKinds         #-}
+{-# LANGUAGE FlexibleContexts  #-}
+{-# LANGUAGE FlexibleInstances #-}
+{-# LANGUAGE Rank2Types        #-}
+{-# LANGUAGE TemplateHaskell   #-}
+{-# LANGUAGE TypeApplications  #-}
+{-# LANGUAGE QuasiQuotes       #-}
 
 #if MIN_VERSION_base(4,19,0)
 {-# OPTIONS_GHC -Wall -Werror -Wno-incomplete-uni-patterns -Wno-x-partial #-}
@@ -42,8 +38,8 @@ import qualified Data.Char       as C
 import qualified Data.SBV.Char   as SC
 import qualified Data.SBV.List   as SL
 
-data Day = Mon | Tue | Wed | Thu | Fri | Sat | Sun deriving (Bounded, Enum, Eq)
-mkSymbolicEnumeration  ''Day
+data Day = Mon | Tue | Wed | Thu | Fri | Sat | Sun deriving (Show, Eq, Enum, Bounded)
+mkSymbolic  [''Day]
 
 -- Test suite
 tests :: TestTree
@@ -449,7 +445,6 @@ genEnums =
 
         -- NB. Precision here is important. If you pick too small of a significand
         -- size then you can turn this enumeration into an infinite list, busting the tests.
-        -- For details see: https://gitlab.haskell.org/ghc/ghc/-/issues/15081
         fps :: [FloatingPoint 5 8]
         fps = [-3.4, -3.2 .. 3.5]
 
@@ -539,6 +534,8 @@ sll = [[x, x, x] | x <- [[], [0], [-1, 1], [-10, 0, 10], [3, 4, 5, 4, 5, 3]]]
 
 -- Quiet GHC about unused enum elts
 _unused :: SDay
-_unused = undefined sMon sTue sWed sThu sFri sSat sSun
+_unused = undefined  sMon  sTue  sWed  sThu  sFri  sSat  sSun
+                    isMon isTue isWed isThu isFri isSat isSun
+                    (sCaseDay @SInteger)
 
 {- HLint ignore module "Reduce duplication" -}
