@@ -9,14 +9,10 @@
 -- Various combinations of quantifiers
 -----------------------------------------------------------------------------
 
-{-# LANGUAGE CPP                 #-}
 {-# LANGUAGE DataKinds           #-}
 {-# LANGUAGE FlexibleContexts    #-}
 {-# LANGUAGE ScopedTypeVariables #-}
-
-#if MIN_VERSION_base(4,19,0)
 {-# LANGUAGE TypeAbstractions    #-}
-#endif
 
 {-# OPTIONS_GHC -Wall -Werror #-}
 
